@@ -279,6 +279,13 @@ SV *sv;
 #endif /* START_MY_CXT */
 
 
+#if 1
+#ifdef DBM_setFilter
+#undef DBM_setFilter
+#undef DBM_ckFilter
+#endif
+#endif
+
 #ifndef DBM_setFilter
 
 /* 
@@ -305,7 +312,7 @@ SV *sv;
 
 #define DBM_ckFilter(arg,type,name)				\
 	if (db->type) {						\
-	    /*printf("Filtering %s\n", name);*/			\
+	    /* printf("Filtering %s\n", name); */		\
 	    if (db->filtering) {				\
 	        croak("recursion detected in %s", name) ;	\
 	    }                     				\
@@ -314,21 +321,22 @@ SV *sv;
 	    SAVEINT(db->filtering) ;				\
 	    db->filtering = TRUE ;				\
 	    SAVESPTR(DEFSV) ;					\
-	    if (1 && name[7] == 's')				\
+	    if (name[7] == 's')  				\
 	        arg = newSVsv(arg);				\
 	    DEFSV = arg ;					\
 	    SvTEMP_off(arg) ;					\
 	    PUSHMARK(SP) ;					\
 	    PUTBACK ;						\
 	    (void) perl_call_sv(db->type, G_DISCARD); 		\
+	    arg = DEFSV ;					\
 	    SPAGAIN ;						\
 	    PUTBACK ;						\
 	    FREETMPS ;						\
 	    LEAVE ;						\
-	    if (1 && name[7] == 's'){				\
+	    if (name[7] == 's'){ 				\
 	        arg = sv_2mortal(arg);				\
 	    }							\
-	        SvOKp(arg);					\
+	    SvOKp(arg);						\
 	}
 
 #endif /* DBM_setFilter */
